
# Type: actively involved in


holds between a continuant and a process or function, where the continuant actively contributes to part or all of the process or function it realizes

URI: [biolink:actively_involved_in](https://w3id.org/biolink/vocab/actively_involved_in)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>0..*</sub> [Occurrent](Occurrent.md)

## Parents

 *  is_a: [participates in](participates_in.md)

## Children

 *  [capable of](capable_of.md)

## Used by

 * [NamedThing](NamedThing.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | RO:0002331 |
| **In Subsets:** | | translator_minimal |

